@@ -19,16 +19,17 @@
 #Date : 12/03/2020
 
 import vmp
-import vmp_plugin as plugin
 
-class Plugin(plugin.PluginInterface):
+PluginName="JrpForensics"
+
+class Plugin(PluginInterfaceType):
   def __init__(self,data,options):
     plugin.PluginInterface.__init__(self,data,options)
     #other operations
 
   #Interface functions redefinition
 
-class PluginTopic(plugin.PluginInterfaceTopic):
+class PluginTopic(PluginInterfaceTopicType):
   def __init__(self,modname,plugname):
     plugin.PluginInterfaceTopic.__init__(self,modname,plugname)
     #set the fields of the topic
