@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 06/11/2024
+#Date last Update : 22/11/2024
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -215,6 +215,6 @@ clibs_[cryptolib.name]=cryptolib
 jrplib=clib()
 jrplib.name='jrp'
 jrplib.dependencies=['vmp','net','event','json','crypto']
-jrplib.files=[('./',['eventjrp','jrp','jrpreq','lib',]),('cb/',['cb','jrpui','wssui']),('misc/',['status'])]
+jrplib.files=[('./',['eventjrp','jrp','jrpreq','lib',]),('cb/',['cb','jrpui','wssui']),('misc/',['misc','utils','status'])]
 clibs_[jrplib.name]=jrplib
 
