@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 05/11/2024
+#Date last Update : 27/11/2024
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -178,7 +178,7 @@ vmp_jrp=pylib()
 vmp_jrp.name='vmp_jrp'
 vmp_jrp.dependencies=['vmp','vmp_net','vmp_event','vmp_crypto','vmp_json','vmp_plugin']
 vmp_jrp.cbuild()
-vmp_jrp.setup.files=[('./',['eventjrp_','jrp_','jrpreq_','status_'])]
+vmp_jrp.setup.files=[('./',['eventjrp_','jrp_','jrpreq_','status_','utils_'])]
 vmp_jrp.setup.dependencies=['pylib','jrp']
 pylibs_[vmp_jrp.name]=vmp_jrp
 
