@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/09/2024
+   Date last update: 27/12/2024
  */
 
 #include "vmp_.h"
@@ -113,8 +113,7 @@ struct stub_signal_wrap:public pylib::Generic_def
                 {
                     pylib::PyCall *tmp=new pylib::PyCall();
                     (*tmp)=arg1;
-                    sigcall_.update(vmp::signum(arg0[i]),&tmp);
-                    if(tmp != 0)
+                    if(sigcall_.update(vmp::signum(arg0[i]),&tmp))
                         delete tmp;
                 }
             }
