@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 04/09/2024
+   Date last update: 11/11/2024
  */
 
 #include "vmp.h"
@@ -118,9 +118,10 @@ void vmp_init_thread(pylib::Module module);
 */
 /*!
     Localtime class in vmp/time.h:<BR>Constructor Localtime(time=0)or Localtime(year,month,day,hour,min,sec)<BR>
-    Localtime member function list:<BR>set(),get_year_days(),set_from_year_day(),next_cronizer(),time(),
-                                       sec(),min(),hour(),mday(),wday(),wday_n(),month(),month_n(),year(),
-                                       ctime(),gmtime(),year_day()
+    Localtime member function list:<BR>
+    set(),get_year_days(),set_from_year_day(),next_cronizer(),
+    time(),sec(),min(),hour(),mday(),wday(),wday_n(),month(),
+    month_n(),year(),ctime(),gmtime(),year_day(),summertime()
 */
 /*!
     Timer class in vmp/time.h:<BR>Constructor Timer()<BR>
