@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 09/02/2024
+ * Date last update: 25/10/2024
  */
 
 #include "vmp.h"
@@ -30,9 +30,13 @@
 //!Python wrapper of the c++ class vampiria::event::Manager in vmp_event.Manager(see c++ doc)
 /*!
     Manager class in event.h:<BR>Constructor Manager()<BR>
-    Manager member function list:<BR>init(),breakloop(),lock(),unlock(),forced_unlock(),recovery_lock(),cell_update(),
-                                     cell_timewait(),cell_close(),cell_close_ok_spec(),cell_close_err_spec(),cell_closewait(),
-                                     time_now(),cell_alloc(),cell_release(),stop(),loop(),
+    Manager member function list:<BR>
+    init(),breakloop(),lock(),unlock(),forced_unlock(),recovery_lock(),
+    cell_update(),cell_timewait(),cell_get_timewait(),cell_get_timeout(),
+    cell_close(),cell_close_ok_spec(),cell_close_err_spec(),cell_closewait(),
+    time_now(),cell_alloc(),cell_release(),cell_set_priority(),cell_get_priority(),
+    stop(),loop(),cell_master(),cell_subid(),cell_addsub(),cell_searchsub(),
+    cell_delsub()
 */
 void event_init_manager(pylib::Module module);
 
@@ -40,11 +44,17 @@ void event_init_manager(pylib::Module module);
 /*! 
     enum wrapper CELLRET(return close status cell) c++ in event.h":<BR>CELLRET_NOCLOSE,CELLRET_SUCCESS,CELLRET_ERROR,CELLRET_TIMEOUT
 */
+/*!
+    const value in event.h:<br>MAX_CELL_PRIORITY
+*/
 /*!
     Cell class in event.h:<BR>No Constructor<BR>
-    Cell member function list:<BR>identity(),close(),close_wait(),close_err(),close_err_spec(),alloc(),release(),ret(),
-                                  str_error(),closelevel(),errcode(),set_timewait(),get_timewait(),get_manager(),
-                                  setvar(),getvar(),remvar(),all_keys()
+    Cell member function list:<BR>
+    identity(),id(),close(),close_wait(),close_err(),close_err_spec(),alloc(),
+    release(),set_priority(),get_priority(),ret(),str_error(),closelevel(),
+    errcode(),set_timewait(),get_timewait(),get_timeout(),get_manager(),
+    setvar(),getvar(),remvar(),all_keys(),master(),subid(),addsub(),searchsub(),
+    delsub()
 */
 void event_init_cell(pylib::Module module);
 
@@ -55,7 +65,8 @@ void event_init_cell(pylib::Module module);
 */
 /*!
    InputUI Class in event/ui/inputui.h:<BR>Constructor InputUI(manager)<BR>
-   InputUI member function list:<BR>set_event(),input()
+   InputUI member function list:<BR>
+   set_event(),input(),isenable(),enable(),disable()
 */
 void event_init_inputui(pylib::Module module);
 
