@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 07/11/2024
+#Date last Update : 08/12/2024
 
 import vmp
 import vmp_event       as event
@@ -64,6 +64,7 @@ def response_d(jreq,data,payload):
 def close_d(jreq):
   cell=jreq.cell()
   plugin=cell.getvar("plugin")
+  plugin.close_i(jreq)
   rid=jreq.rid()
   request=plugin.requests[rid]
   request.status=jreq.status()
@@ -111,9 +112,10 @@ def connect(plugin,args):
       plugin.vars={}
       plugin.peerstatus="connecting"
     except Exception as e:
-      vmp.output("{0}".format(str(e)))
+      vmp.error("{0}".format(str(e)))
   else:
-    vmp.output("Client already connected to a peer")
+    vmp.error("Client already connected to a peer")
+    vmp.time.vsleep(0.1)
   
 def connectstatus(plugin,args):
   if plugin.peerstatus == "close":
@@ -135,17 +137,18 @@ def disconnect(plugin,args):
     plugin.iblock=True
     plugin.peer.close()
   else:
-    vmp.output("Peer already disconnect")
-  
+    vmp.error("Peer already disconnect")
+    vmp.time.vsleep(0.1)
+
 def requests(plugin,args):
   requests=dict(sorted(plugin.requests.items()))
-  vmp.output("|  rid  |    type    | status  |         exit message           | forward")
+  vmp.output("|  rid  |          type           | status  |  exit message")
   for req in requests:
     data=requests[req]
     if data.status == 'open':
-      vmp.output("| {0:^5} |  {1:^5}   |  open   | {2:^30} | {3}".format(req,data.type,'',data.forward))
+      vmp.output("| {0:^5} |  {1:^20}   |  open   | {2:^30}".format(req,data.type,''))
     else:
-      vmp.output("| {0:^5} |  {1:^5}   | {2:^6}  | {3:^30} | {4}".format(req,data.type,data.status,data.msg,data.forward))
+      vmp.output("| {0:^5} |  {1:^20}   | {2:^6}  |   {3}".format(req,data.type,data.status,data.msg))
   
 def kill(plugin,args):
   if args[0] in plugin.requests:
@@ -173,30 +176,135 @@ def varars(plugin,args):
     if args[0] in plugin.vars and args[1] in plugin.vars[args[0]]:
       vmp.output("{0}".format(plugin.vars[args[0]][args[1]].value))
     else:
-      vmp.output("Var ({0},{1}) not found".format(args[0],args[1]))
-  
+      vmp.error("Var ({0},{1}) not found".format(args[0],args[1]))
+      vmp.time.vsleep(0.1)
+
 def status(plugin,args):
   try:
-    if len(args) == 1:
-      sid=args[0]
-    else:
-      sid=""
     j=json.Json()
-    json.japi_status(j.root(),sid)
+    json.japi_status(j.root())
     plugin.send_request(j.root())
-    vmp.output("Result in section var 'status_{0}'".format(sid))
+    vmp.output("Result in section var 'status'")
   except Exception as e:
-    vmp.output(str(e))
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
 
+def userlist(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('userinfo')
+    j=json.Json()
+    json.japi_userlist(j.root())
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'userinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
+def useradd(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('userinfo')
+    j=json.Json()
+    json.japi_useradd(j.root(),args[0],args[1],args[2],args[3])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'userinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
+def usermod(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('userinfo')
+    j=json.Json()
+    json.japi_usermod(j.root(),args[0],args[1],args[2])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'userinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
+def userpasswd(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('userinfo')
+    j=json.Json()
+    json.japi_userpasswd(j.root(),args[0],args[1])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'userinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+    
+def userdel(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('userinfo')
+    j=json.Json()
+    json.japi_userdel(j.root(),args[0])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'userinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
+def peerlist(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('peerinfo')
+    j=json.Json()
+    json.japi_peerlist(j.root())
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'peerinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
+def peeradd(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('peerinfo')
+    j=json.Json()
+    json.japi_peeradd(j.root(),args[0],args[1],args[2])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'peerinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+    
+def peermod(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('peerinfo')
+    j=json.Json()
+    json.japi_peermod(j.root(),args[0],args[1])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'peerinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+
+def peerdel(plugin,args):
+  try:
+    plugin.busy()
+    plugin.newsectionvar('peerinfo')
+    j=json.Json()
+    json.japi_peerdel(j.root(),args[0])
+    plugin.send_request(j.root())
+    vmp.output("Result in section var 'peerinfo'")
+  except Exception as e:
+    vmp.error(str(e))
+    vmp.time.vsleep(0.1)
+   
 #Internal usage
 class Requests:
   def __init__(self,jreq):
     self.jreq=jreq
-    self.type=jreq.type()
+    self.type=jreq.jdata_type()
     self.status="open"
     self.msg=''
-    self.forward=jreq.forward()
-
+    
 class Var:
   def __init__(self,value,desc):
     self.value=value
@@ -240,6 +348,13 @@ class Cmd:
             maxvalue=t[3]
           v=vmp.unicode.str_toreal_range(args[i],minvalue,maxvalue)
           retargs.append(v)
+        elif t[1] == 'boolean':
+          if args[i] == 'true':
+            retargs.append(True)
+          elif args[i] == 'false':
+            retargs.append(False)
+          else:
+            vmp.except_s("{0} not boolean type".format(args[i]))
         elif t[1] == 'hex':
           if not str_istype(args[i],"xdigit"):
             vmp.except_s("{0} not exadecimal type".format(args[i]))
@@ -293,9 +408,17 @@ class Plugin(base.Plugin):
     self.add_command("requests","List of requests sent",0,[],requests)
     self.add_command("kill","Send a kill message to a request ",1,[("request number",'integer',0,None)],kill)
     self.add_command("quit","Exit console",0,[],quit,False)
-    self.add_command("status","Send a jrp status request",0,[("id status",'generic')],status)
+    self.add_command("status","Send a jrp status request",0,[],status)
     self.add_command("vars","Print section list if argument is not specified,print variable list if section is specified,print variable value if section variable is specified",0,[('session name','generic'),('variable name','generic')],varars)
-    
+    self.add_command("userlist","List of web users",0,[],userlist)
+    self.add_command("useradd","Add a web user",4,[('web user','generic'),('user password','generic'),('user permits','integer',0,vmp.INTMAX),('if access is allowed only in localhost','boolean')],useradd)
+    self.add_command("usermod","Change ownership of a web user",3,[('web user','generic'),('user permits','integer',0,vmp.INTMAX),('if access is allowed only in localhost','boolean')],usermod)
+    self.add_command("userpasswd","Change password of a web user",2,[('web user','generic'),('user password','generic')],userpasswd)
+    self.add_command("userdel","Delete a web user's password",1,[('web user','generic')],userdel)
+    self.add_command("peerlist","List of peers",0,[],peerlist)
+    self.add_command("peeradd","Add a peer",3,[('fingerprint peer','generic'),('subject peer','generic'),('user permits','integer',0,vmp.INTMAX)],peeradd)
+    self.add_command("peermod","Change ownership of a peer",2,[('fingerprint peer','generic'),('user permits','integer',0,vmp.INTMAX)],peermod)
+    self.add_command("peerdel","Delete a peer",1,[('fingerprint','generic')],peerdel)
     self.ctx=crypto.Ctx_Peer(vmp.fs.union_path(self.rootpath,"x509"),1,self.subject)
     
     if self.debug:
@@ -316,9 +439,18 @@ class Plugin(base.Plugin):
     self.exitmsg=""
     self.requests={}
     self.vars={}
+    self.busystate=False
     
     self.prompt()
    
+  def busy(self):
+    if self.busystate:
+      vmp.except_s("Request Manager is busy")
+    self.busystate=True
+  
+  def unbusy(self):
+    self.busystate=False
+    
   def prompt(self):
     if self.prompt_active:
       vmp.output_raw("ragnu>");
@@ -338,6 +470,8 @@ class Plugin(base.Plugin):
   #
   #@param name section name
   def newsectionvar(self,name):
+    if name in self.vars:
+      self.delsectionvar(name)
     self.vars[name]={}
   
   ##Remove an section from list
@@ -415,6 +549,7 @@ class Plugin(base.Plugin):
   #argtype :
   #'generic' - generic arguments
   #'integer' - integer value var arguments=(minvalue='',maxvalue='') ''=not assigned
+  #'boolean' - boolean value
   #'real'    - integer value var arguments=(minvalue='',maxvalue='') ''=not assigned
   #'hex'     - hexadecimal value
   #'ip'      - ip value
@@ -446,8 +581,8 @@ class Plugin(base.Plugin):
           else:
             vmp.except_s("Command '{0}' not found".format(cmd)) 
       except Exception as e:
-        vmp.output(str(e))
-        vmp.time.vsleep(0.2)
+        vmp.error(str(e))
+        vmp.time.vsleep(0.1)
     if not self.iblock:
       self.prompt()
   
@@ -456,26 +591,53 @@ class Plugin(base.Plugin):
     jd=json.JData()
     jd.set(jdata)
     if jd.jtype() == json.japi("statusupdate"):
-      sid="status_{0}".format(jd.get_text("id"))
       key=jd.get_text("key")
       jobj=json.JsonObj()
       j=json.Json()
       jd.get_subtype("data",jobj)
       j.json_new_obj(jobj)
-      self.setvar(sid,key,j.json_str(),"status update vars")
+      self.setvar('status',key,j.json_str(),"status update var")
     elif jd.jtype() == json.japi("statuscancel"):
-      sid="status_{0}".format(jd.get_text("id"))
       key=jd.get_text("key")
-      self.delvar(sid,key)
+      self.delvar('status',key)
+    elif jd.jtype() == json.japi("peerinfo"):
+      fng=jd.get_text("fingerprint")
+      d={'fingerprint':fng,'subject':jd.get_text('subject'),'permits':jd.get_integer_range('permits',0,vmp.INTMAX)}
+      value="{0}".format(d)
+      self.setvar('peerinfo',fng,value,"peer info")
+    elif jd.jtype() == json.japi("userinfo"):
+      user=jd.get_text("user")
+      if jd.get_bool("only_localhost"):
+        o="True"
+      else:
+        o="False"
+      d={'user':user,'permits':jd.get_integer_range('permits',0,vmp.INTMAX),'only_localhost':o}
+      value="{0}".format(d)
+      self.setvar('userinfo',user,value,"user '{0}' info".format(user))
     else:
       self.response(jreq,jdata)
     
+  #Internal usage
+  def close_i(self,jreq):
+    jd=json.JData()
+    jd.set(jreq.jdata_root())
+    t=jd.jtype()
+    if (t == json.japi("userlist")) or (t == json.japi("useradd")) or (t == json.japi("usermod")) or (t == json.japi("userpasswd")) or (t == json.japi("userdel")) or (t == json.japi("peerlist")) or (t == json.japi("peeradd")) or (t == json.japi("peermod")) or (t == json.japi("peerdel")):
+      self.unbusy()
+    self.close(jreq)
+    
   ##Virtual function for the management of incoming responses
   #
   #@param jreq json request associated
   #@param jdata jsonObject data recv
   def response(self,jreq,djata):
     pass
+    
+  ##Virtual function for the management close response
+  #
+  #@param jreq json request associated
+  def close(self,jreq):
+    pass
        
 ##Plugin interface topic
 class PluginTopic(base.PluginTopic):
@@ -488,6 +650,8 @@ class PluginTopic(base.PluginTopic):
     self.add_data("Print the video prompt?(boolean)")
     self.add_data("Run in debug mode?(boolean)")
     self.add_data("Proxychain connection data,if none not proxy used")
+    self.add_function("busy","Occupy the request manager for operations that need to be done one at a time")
+    self.add_function("unbusy","Occupy the request manager for operations that need to be done one at a time",[],"void or except in case the request manager is busy")
     self.add_function("prompt","Print the prompt on the screen")
     self.add_function("newsectionvar","Create new section var",[('name','variable name')])
     self.add_function("delsectionvar","Delete section var",[('name','variable name')])
@@ -499,5 +663,6 @@ class PluginTopic(base.PluginTopic):
     self.add_function("add_command","Add command to plugin",[('name','command name'),('helper','helper string'),('minargs','minimum number of arguments'),('args','arguments list description (see doxygen doc in plugin type)'),('callback','callback function to run command (see doxygen doc in plugin type)'),('prompt','if true active prompt')])
     self.add_function("command","Send the plugin a command to run",[('cmdline','command string')])
     self.add_function("response","Virtual function for the management of incoming responses",[('jreq','json request associated'),('jdata','json object data recv')])
+    self.add_function("close","Virtual function for the management close requests",[('jreq','json request associated')])
     
     
