@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 15/10/2024
+ * Date last update: 26/11/2024
  */
  
 #include "jrp_.h"
@@ -280,17 +280,6 @@ struct stub_JrpUI_request:public pylib::Member_def<PyJrpUI>
             return pylib::Converter<jrp::JrpReq *>(req,false);
             
         }
-        else if(args.size() == 4)
-        {
-            event::Cell *cell=args.get<event::Cell *>(0);
-            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
-            vmp::Buf *payload=0;
-            if(!args.is_none(2))
-                payload=args.get<vmp::Buf *>(2);
-            vmp::str forward=args.get<vmp::str>(3);
-            jrp::JrpReq *req=instance->request(cell,jdata,payload,forward);
-            return pylib::Converter<jrp::JrpReq *>(req,false);
-        }
         return 0;
      }
 };
@@ -317,17 +306,6 @@ struct stub_JrpUI_request_f:public pylib::Member_def<PyJrpUI>
             return pylib::Converter<jrp::JrpReq *>(req,false);
             
         }
-        else if(args.size() == 4)
-        {
-            vmp::str fingerprint=args.get<vmp::str>(0);
-            json::JsonObj *jdata=args.get<json::JsonObj *>(1);
-            vmp::Buf *payload=0;
-            if(!args.is_none(2))
-                payload=args.get<vmp::Buf *>(2);
-            vmp::str forward=args.get<vmp::str>(3);
-            jrp::JrpReq *req=instance->request_f(fingerprint,jdata,payload,forward);
-            return pylib::Converter<jrp::JrpReq *>(req,false);
-        }
         return 0;
     }
 };
@@ -609,11 +587,9 @@ void jrp_init(pylib::Module module)
     jrpui.def_("peer_permits",&PyJrpUI::peer_permits);
     jrpui.def_("peer_permits_f",&PyJrpUI::peer_permits_f);
     jrpui.def_("peer_nodetype",&PyJrpUI::peer_nodetype);
-    jrpui.def_("peer_forward",&PyJrpUI::peer_forward);
     jrpui.def_("peer_subject_f",&PyJrpUI::peer_subject_f);
     jrpui.def_("peer_permits_f",&PyJrpUI::peer_permits_f);
     jrpui.def_("peer_nodetype_f",&PyJrpUI::peer_nodetype_f);
-    jrpui.def_("peer_forward_f",&PyJrpUI::peer_forward_f);
     jrpui.def_with_stub("search_peer",stub_JrpUI_search_peer());
     jrpui.def_("search_peer_p",&PyJrpUI::search_peer_p);
     jrpui.def_("search_peer_o",&PyJrpUI::search_peer_o);
@@ -659,6 +635,7 @@ void vampiria_pylib_init_module(pylib::Module init_module)
     
     pylib::Module misc=init_module.add_submodule("misc");
     jrp_misc_status(misc);
+    jrp_misc_utils(misc);
 }
 
  
