@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 06/11/2024
+#Date last Update : 22/11/2024
 
 from vmp_json_  import Json    as Json
 from vmp_json_  import JsonObj as JsonObj
@@ -41,4 +41,17 @@ from vmp_json_  import japi_status_cancel as japi_status_cancel
 from vmp_json_  import japi_login         as japi_login
 from vmp_json_  import japi_login_b64_e   as japi_login_b64_e
 from vmp_json_  import japi_login_b64_d   as japi_login_b64_d
+from vmp_json_  import japi_passwd        as japi_passwd
+from vmp_json_  import japi_userlist      as japi_userlist
+from vmp_json_  import japi_userinfo      as japi_userinfo
+from vmp_json_  import japi_useradd       as japi_useradd
+from vmp_json_  import japi_usermod       as japi_usermod
+from vmp_json_  import japi_userpasswd    as japi_userpasswd
+from vmp_json_  import japi_userdel       as japi_userdel
+from vmp_json_  import japi_peerlist      as japi_peerlist
+from vmp_json_  import japi_peerinfo      as japi_peerinfo
+from vmp_json_  import japi_peeradd       as japi_peeradd
+from vmp_json_  import japi_peermod       as japi_peermod
+from vmp_json_  import japi_peerdel       as japi_peerdel
+
 
