@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 19/09/2024
+ * Date last update: 22/11/2024
  */
 
 #include "json_.h"
@@ -192,74 +192,6 @@ struct stub_japi_oper_push:public pylib::Generic_def
     }
 };
 
-struct stub_japi_status:public pylib::Generic_def
-{
-    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 1)
-        {
-            json::JsonObj *obj=args.get<json::JsonObj *>(0);
-            json::japi_status(obj);
-            return pylib::retnone(); 
-        }
-        else if(args.size() == 2)
-        {
-            json::JsonObj *obj=args.get<json::JsonObj *>(0);
-            vmp::str id=args.get<vmp::str>(1);
-            json::japi_status(obj,id);
-            return pylib::retnone();
-        }
-        return 0;
-    }
-};
-
-struct stub_japi_status_update:public pylib::Generic_def
-{
-    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 3)
-        {
-            json::JsonObj *obj=args.get<json::JsonObj *>(0);
-            vmp::str key=args.get<vmp::str>(1);
-            json::JsonObj *data=args.get<json::JsonObj *>(2);
-            json::japi_status_update(obj,key,data);
-            return pylib::retnone(); 
-        }
-        else if(args.size() == 4)
-        {
-            json::JsonObj *obj=args.get<json::JsonObj *>(0);
-            vmp::str key=args.get<vmp::str>(1);
-            json::JsonObj *data=args.get<json::JsonObj *>(2);
-            vmp::str id=args.get<vmp::str>(3);
-            json::japi_status_update(obj,key,data,id);
-            return pylib::retnone();
-        }
-        return 0;
-    }
-};
-
-struct stub_japi_status_cancel:public pylib::Generic_def
-{
-    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
-    {
-        if(args.size() == 2)
-        {
-            json::JsonObj *obj=args.get<json::JsonObj *>(0);
-            vmp::str key=args.get<vmp::str>(1);
-            json::japi_status_cancel(obj,key);
-            return pylib::retnone(); 
-        }
-        else if(args.size() == 3)
-        {
-            json::JsonObj *obj=args.get<json::JsonObj *>(0);
-            vmp::str key=args.get<vmp::str>(1);
-            vmp::str id=args.get<vmp::str>(2);
-            json::japi_status_cancel(obj,key,id);
-            return pylib::retnone();
-        }
-        return 0;
-    }
-};
 
 struct stub_japi_login:public pylib::Generic_def
 {
@@ -307,6 +239,86 @@ struct stub_japi_login_b64_e:public pylib::Generic_def
     }
 };
 
+struct stub_japi_passwd:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 3)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str oldpassword=args.get<vmp::str>(1);
+            vmp::str password=args.get<vmp::str>(2);
+            json::japi_passwd(obj,oldpassword,password);
+            return pylib::retnone();
+        }
+        else if(args.size() == 4)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str oldpassword=args.get<vmp::str>(1);
+            vmp::str password=args.get<vmp::str>(2);
+            vmp_bool md5_password=args.get<vmp_bool>(3);
+            json::japi_passwd(obj,oldpassword,password,md5_password);
+            return pylib::retnone();
+        }
+        return 0;
+    }
+};
+
+struct stub_japi_useradd:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 5)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str user=args.get<vmp::str>(1);
+            vmp::str password=args.get<vmp::str>(2);
+            vmp_uint permits=args.get<vmp_uint>(3);
+            vmp_bool only_localhost=args.get<vmp_bool>(4);
+            json::japi_useradd(obj,user,password,permits,only_localhost);
+            return pylib::retnone();
+        }
+        else if(args.size() == 6)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str user=args.get<vmp::str>(1);
+            vmp::str password=args.get<vmp::str>(2);
+            vmp_uint permits=args.get<vmp_uint>(3);
+            vmp_bool only_localhost=args.get<vmp_bool>(4);
+            vmp_bool md5_password=args.get<vmp_bool>(5);
+            json::japi_useradd(obj,user,password,permits,only_localhost,md5_password);
+            return pylib::retnone();
+        }
+        return 0;
+    }
+};
+
+struct stub_japi_userpasswd:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 3)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str user=args.get<vmp::str>(1);
+            vmp::str password=args.get<vmp::str>(2);
+            json::japi_userpasswd(obj,user,password);
+            return pylib::retnone();
+        }
+        else if(args.size() == 4)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str user=args.get<vmp::str>(1);
+            vmp::str password=args.get<vmp::str>(2);
+            vmp_bool md5_password=args.get<vmp_bool>(3);
+            json::japi_userpasswd(obj,user,password,md5_password);
+            return pylib::retnone();
+        }
+        
+        return 0;
+    }
+};
+
 void json_japi(pylib::Module module)
 {
     module.def_("japi",json::japi);
@@ -320,11 +332,23 @@ void json_japi(pylib::Module module)
     module.def_with_stub("japi_oper_data",stub_japi_oper_data());
     module.def_with_stub("japi_oper_push",stub_japi_oper_push());
     module.def_("japi_oper_close",json::japi_oper_close);
-    module.def_with_stub("japi_status",stub_japi_status());
-    module.def_with_stub("japi_status_update",stub_japi_status_update());
-    module.def_with_stub("japi_status_cancel",stub_japi_status_cancel());
+    module.def_("japi_status",json::japi_status);
+    module.def_("japi_status_update",json::japi_status_update);
+    module.def_("japi_status_cancel",json::japi_status_cancel);
     module.def_with_stub("japi_login",stub_japi_login());
     module.def_with_stub("japi_login_b64_e",stub_japi_login_b64_e());
     module.def_("japi_login_b64_d",json::japi_login_b64_d);
+    module.def_with_stub("japi_passwd",stub_japi_passwd());
+    module.def_("japi_userlist",json::japi_userlist);
+    module.def_("japi_userinfo",json::japi_userinfo);
+    module.def_with_stub("japi_useradd",stub_japi_useradd());
+    module.def_("japi_usermod",json::japi_usermod);
+    module.def_with_stub("japi_userpasswd",stub_japi_userpasswd());
+    module.def_("japi_userdel",json::japi_userdel);
+    module.def_("japi_peerlist",json::japi_peerlist);
+    module.def_("japi_peerinfo",json::japi_peerinfo);
+    module.def_("japi_peeradd",json::japi_peeradd);
+    module.def_("japi_peermod",json::japi_peermod);
+    module.def_("japi_peerdel",json::japi_peerdel);
 }
 
