@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 06/11/2024
+ * Date last update: 22/11/2024
  */
 
 #include "pylib.h"
@@ -91,7 +91,9 @@ void json_jtable(pylib::Module module);
 /*!
     Function c++ in json/japi.h:<BR>japi(),japi_type_list(),japi_type_table(),japi_void(),japi_list(),japi_table(),
                                     japi_oper(),japi_oper_kill(),japi_oper_data(),japi_oper_push(),japi_oper_close(),japi_status(),
-                                    japi_status_update(),japi_status_cancel(),japi_login(),japi_login_b64_e(),japi_login_b64_d()
+                                    japi_status_update(),japi_status_cancel(),japi_login(),japi_login_b64_e(),japi_login_b64_d(),
+                                    japi_passwd(),japi_userlist(),japi_userinfo(),japi_useradd(),japi_usermod(),japi_userpasswd(),
+                                    japi_userdel(),japi_peerlist(),japi_peerinfo(),japi_peeradd(),japi_peermod(),japi_peerdel()
 */
 void json_japi(pylib::Module module);
 
