@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/11/2020
+   Date last update: 05/09/2024
  */
 
 #include "packet_.h"
@@ -107,4 +107,7 @@ void packet_init(pylib::Module module)
 void vampiria_pylib_init_module(pylib::Module init_module)
 {
      packet_init(init_module);
+     packet_init_http(init_module);
+     packet_init_websocket(init_module);
 }
+
