@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 15/05/2020
+ * Date last update: 11/11/2023
  */
 
 #include "event.h"
@@ -90,6 +90,11 @@ void EventTimer::evt_timer_deactive()
     evt_timer_active(0.0);    
 }
 
+vmp_bool EventTimer::evt_timer_isactive()
+{
+    return active_;
+}
+
 void EventTimer::evt_timer_close()
 {
     evt_close();
