@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 14/01/2023
+   Date last update: 22/10/2024
  */
 
 #include "event.h"
@@ -27,6 +27,10 @@ void empty_ev(event::Cell *cell)
 {
 }
 
+void empty_close_ev(event::Cell *cell,vmp_int retcode,vmp::str retmsg)
+{
+}
+
 void empty_buf_ev(event::Cell *cell,vmp::Buf *buf)
 {
 }
@@ -40,20 +44,14 @@ Event::Event()
     priority_=0;
     fd_=-1;
     cell_=0;
+    master_=0;
+    sid_="";
 }
         
 Event::~Event()
 {
 }
 
-void Event::set_priority(vmp_int priority)
-{
-    if(priority < event::MAX_CELL_PRIORITY)
-       priority_=priority;
-    else
-       priority_=event::MAX_CELL_PRIORITY;
-}
-
 event::Cell *Event::evt_new(event::UI *ui,vmp_int fd,event::EVTCB read,event::EVTCB close)
 {
    vmp::except_check_pointer((void *)ui,"event::Event::evt_new() null input ui");
@@ -72,6 +70,11 @@ void Event::evt_active(vmp_bool active)
 
 void Event::evt_close()
 {
+    //!close subs event
+    event::Manager *manager=cell_->get_manager();
+    vmp::vector<event::Cell *> cells=evtsubs_.all_data();
+    for(vmp_index i=0;i<cells.size();i++)
+        manager->cell_close_ok_spec(cells[i],"net::EventSub");
 }
 
 void Event::evt_free()
@@ -79,6 +82,8 @@ void Event::evt_free()
    priority_=0;
    fd_=-1;
    cell_=0;
+   sid_="";
+   evtsubs_.clear();
 }
 
 EventPipe::EventPipe():Event()
