@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/02/2024
+   Date last update: 24/10/2024
  */
 
 #include "event.h"
@@ -25,6 +25,7 @@ namespace vampiria { namespace event {
 
 Manager::Manager()
 {
+    cellids_=1;
     timer_.init();
     self_=vmp::thread::pthread_self_wrap();
     init_=false;
@@ -38,6 +39,13 @@ Manager::~Manager()
     breakui_=0;
 }
 
+void Manager::cell_freedata(event::Cell *cell)
+{
+    event::Cell *master=cell_master(cell);
+    vmp::str sid=cell_subid(cell);
+    cell_delsub(master,sid);
+}
+
 void Manager::init()
 {
     lock();
@@ -83,12 +91,14 @@ event::Cell *Manager::cell_new(event::UI *ui,event::Event *event,vmp_int priorit
     if(!init_)
         vmp::except_s("event::Manager::cell_new() event Manager not initialized");
     event::Cell *cell=cellref_.get();
+    if(cell->id_ == 0)
+      cell->id_=cellids_++;
     cell->reset();
     cell->ui_=ui;
     cell->event_=event;
     event->cell_=cell;
     cell->manager_=this;
-    cell->priority_=priority;
+    cell_set_priority(cell,priority);
     cell->writing_=false;
     if(read == 0)
       cell->read_=event::empty_ev;
@@ -106,8 +116,10 @@ event::Cell *Manager::cell_new(event::UI *ui,event::Event *event,vmp_int priorit
 
 vmp_bool Manager::cell_update(event::Cell *cell)
 {
+    if(cell == 0)
+        return false;
     if(cell->state_ == event::CLOSE)
-       return false;
+        return false;
     if(cell->state_ == event::CLOSEWAIT)
     {
         if(cell->nwait_ == 0)
@@ -115,28 +127,41 @@ vmp_bool Manager::cell_update(event::Cell *cell)
         cell->nwait_--;
     }
     if(cell->timewait_ != 0.0)
-       cell->timeout_=time_now()+cell->timewait_;
-    return true;
+        cell->timeout_=time_now()+cell->timewait_;
+    return true;void set_priority(vmp_int priority);
 }
 
 void Manager::cell_timewait(event::Cell *cell,vmp::time::Time timewait)
 {
-    if(timewait > 0.0)
+    if(cell != 0)
     {
-        cell->timewait_=timewait;
-        cell->timeout_=time_now()+cell->timewait_;
+        if(timewait > 0.0)
+        {
+            cell->timewait_=timewait;
+            cell->timeout_=time_now()+cell->timewait_;
+        }
+        else
+        {
+            cell->timewait_=0.0;
+            cell->timeout_=0.0;
+        }
+        breakloop();
     }
-    else
-    {
-        cell->timewait_=0.0;
-        cell->timeout_=0.0;
-    }
-    breakloop();
+}
+
+vmp::time::Time Manager::cell_get_timewait(event::Cell *cell)
+{
+    return cell->timewait_;
+}
+
+vmp::time::Time Manager::cell_get_timeout(event::Cell *cell)
+{
+    return cell->timeout_;
 }
 
 void Manager::cell_close(event::Cell *cell,event::CELLRET retcode,vmp::str errinfo)
 {
-    if(cell->state_ != event::CLOSE)
+    if((cell != 0) && (cell->state_ != event::CLOSE))
     {
         cell->ret_=retcode;
         cell->err_=errinfo;
@@ -148,21 +173,33 @@ void Manager::cell_close(event::Cell *cell,event::CELLRET retcode,vmp::str errin
 
 void Manager::cell_close_ok_spec(event::Cell *cell,vmp::str closelevel)
 {
-    cell->closelevel_=closelevel;
-    cell_close(cell,event::SUCCESS);
-        
+    if((cell != 0) && (cell->state_ != event::CLOSE))
+    {
+        cell->closelevel_=closelevel;
+        cell->ret_=event::SUCCESS;
+        cell->state_=event::CLOSE;
+        cell->ui_->close_event(cell);
+        breakloop();
+    }
 }
 
 void Manager::cell_close_err_spec(event::Cell *cell,vmp::str closelevel,vmp_int errcode,vmp::str errinfo)
 {
-    cell->closelevel_=closelevel;
-    cell->errcode_=errcode;
-    cell_close(cell,event::ERROR,errinfo);
+    if((cell != 0) && (cell->state_ != event::CLOSE))
+    {
+        cell->closelevel_=closelevel;
+        cell->errcode_=errcode;
+        cell->ret_=event::ERROR;
+        cell->err_=errinfo;
+        cell->state_=event::CLOSE;
+        cell->ui_->close_event(cell);
+        breakloop();
+    }
 }
 
 void Manager::cell_closewait(event::Cell *cell,vmp_uint n,vmp::str closelevel)
 {
-   if(cell->state_ == event::ACTIVE)
+   if((cell != 0) && (cell->state_ == event::ACTIVE))
    {
        if(n == 0)
            cell_close_ok_spec(cell,closelevel);
@@ -181,7 +218,7 @@ vmp::time::Time Manager::time_now()
 }
 
 void Manager::set_timeout(vmp::time::Time timeout)
-{
+{void set_priority(vmp_int priority);
     if(timeout > 0.0)
     {
        if((timeout_ == 0.0) || (timeout < timeout_))
@@ -191,21 +228,91 @@ void Manager::set_timeout(vmp::time::Time timeout)
 
 void Manager::cell_alloc(event::Cell *cell)
 {
-    cell->refalloc_++;
+    if(cell != 0)
+        cell->refalloc_++;
 }
 
 void Manager::cell_release(event::Cell *cell)
 {
-    if(cell->refalloc_ > 1)
-        cell->refalloc_--;
-    else if (cell->refalloc_ == 1)
+    if(cell != 0)
     {
-        cell->refalloc_=0;
-        cell->ui_->free_ref(cell);
-        cellref_.free(cell);
+        if(cell->refalloc_ > 1)
+            cell->refalloc_--;
+        else if (cell->refalloc_ == 1)
+        {
+            cell->refalloc_=0;
+            cell->ui_->free_ref(cell);
+            cellref_.free(cell);
+        }
+        else
+            vmp::warning_s("event::Manager::cell_release() cell already released");
     }
+}
+
+void Manager::cell_set_priority(event::Cell *cell,vmp_uint priority)
+{
+    if(priority < event::MAX_CELL_PRIORITY)
+       cell->priority_=priority;
     else
-        vmp::warning_s("event::Manager::cell_release() cell already released");
+       cell->priority_=event::MAX_CELL_PRIORITY;
+}
+
+vmp_uint Manager::cell_get_priority(event::Cell *cell)
+{
+    return cell->priority_;
+}
+
+event::Cell *Manager::cell_master(event::Cell *cell)
+{
+    if(cell != 0)
+        return cell->event_->master_;
+    return 0;
+}
+
+vmp::str Manager::cell_subid(event::Cell *cell)
+{
+    if(cell != 0)
+        return cell->event_->sid_;
+    return "";
+}
+
+void Manager::cell_addsub(event::Cell *cell,vmp::str sid,event::Cell *sub)
+{
+    if((cell != 0) && (sub != 0))
+    {
+        cell->event_->evtsubs_.insert(sid,sub);
+        sub->event_->sid_=sid;
+        sub->event_->master_=cell;
+        cell_alloc(cell);
+        cell_alloc(sub);
+    }
+}
+
+event::Cell *Manager::cell_searchsub(event::Cell *cell,vmp::str sid)
+{
+    event::Cell *ret=0;
+    if(cell != 0)
+        cell->event_->evtsubs_.search(sid,&ret);
+    return ret;
+}
+
+void Manager::cell_delsub(event::Cell *cell,vmp::str sid)
+{
+    if(cell != 0)
+    {
+        event::Cell *ret=0;
+        try
+        {
+            cell->event_->evtsubs_.cancel(sid,&ret);
+            ret->event_->master_=0;
+            ret->event_->sid_="";
+            cell_release(ret);
+            cell_release(cell);
+        }
+        catch(vmp::exception &x)
+        {
+        }
+    }
 }
 
 void Manager::stop()
@@ -260,7 +367,10 @@ void Manager::loop()
                 forced_unlock();
                 vmp::error("event::Manager::loop() close(%s) (%s)",cell->identity().c_str(),x.what());
             }
-            cell->release();
+            lock();
+            cell_freedata(cell);
+            cell_release(cell);
+            unlock();
         }
         lock();
         for(vmp_index i=0;i<vread.size();i++)
