@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 15/10/2024
+   Date last update: 30/11/2024
 */
 
 #include "vmp.h"
@@ -58,8 +58,8 @@ const vmp_int status_kill_notcomplete=-16;/*!<User by jrp protocol for message s
 const vmp_int status_forward_denied=-17;/*!<User by jrp protocol for message states 'Forward Denied'*/
 const vmp_int status_request_overflow=-18;/*!<User by jrp protocol for message states 'Overflow request'*/
 
-const vmp_index min_permits=1;/*!<Minimum limit of JRP permits*/
-const vmp_index max_permits=vmp::UINT16MAX;/*!<Maximum limit of JRP permissions*/
+const vmp_index min_permits=0;/*!<Minimum limit of JRP permits*/
+const vmp_index max_permits=255;/*!<Maximum limit of JRP permissions*/
 
 //! Takes in input a Jrp int status is returns the associated status string 
 /*!
@@ -257,13 +257,6 @@ class JrpUI:public event::UI
         */
         vmp::str peer_nodetype(event::Cell *cell);
         
-        //! Returns true if peer accepts forward packets
-        /*!
-            @param cell event cell
-            @return nodetype peer
-        */
-        vmp_bool peer_forward(event::Cell *cell);
-        
         //! Returns the subject of the peer associated with the input fingerprint(monitor mode) 
         /*!
             @param fingerprint input fingerprint
@@ -285,13 +278,6 @@ class JrpUI:public event::UI
         */
         vmp::str peer_nodetype_f(vmp::str fingerprint);
         
-        //! Returns true if peer accepts forward packets
-        /*!
-            @param fingerprint input fingerprint
-            @return nodetype peer
-        */
-        vmp_bool peer_forward_f(vmp::str fingerprint);
-        
         //! Returns the fingerprints of the peer associated with the input fingerprint(monitor mode)       
         /*!
             @param input input request data required(input ="" return all peer fingerprint)
@@ -410,20 +396,18 @@ class JrpUI:public event::UI
             @param cell input cell
             @param jdata jdata inputstefano orsi
             @param payload payload data
-            @param forward forward peer(if == "" request not forwarding)
             @return the structure associated with the request or except in case of failure("Overflow request" if the number of requests exceeds the maximum number)
         */
-        jrp::JrpReq *request(event::Cell *cell,json::JsonObj *jdata,vmp::Buf *payload=0,vmp::str forward="");
+        jrp::JrpReq *request(event::Cell *cell,json::JsonObj *jdata,vmp::Buf *payload=0);
 
         //!Send a request jrp a peer associated with the fingerprint(monitor mode)
         /*!
             @param fingerprint input cell
             @param jdata jdata input
             @param payload payload data
-            @param forward forward peer(if == "" request not forwarding)
-            @return the structure associated with the request or except in case of failure("Overflow request" if the number of requests exceeds the maximum number)
+           @return the structure associated with the request or except in case of failure("Overflow request" if the number of requests exceeds the maximum number)
         */
-        jrp::JrpReq *request_f(vmp::str fingerprint,json::JsonObj *jdata,vmp::Buf *payload=0,vmp::str forward="");
+        jrp::JrpReq *request_f(vmp::str fingerprint,json::JsonObj *jdata,vmp::Buf *payload=0);
         
         //! Send a jrp broadcast message(monitor mode)
         /*!
