@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 15/10/2024
+   Date last update: 30/11/2024
 */
 
 #include "jrp.h"
@@ -379,16 +379,6 @@ vmp::str JrpUI::peer_nodetype(event::Cell *cell)
     return ret;
 }
 
-vmp_bool JrpUI::peer_forward(event::Cell *cell)
-{
-    event::Manager *manager=cell->get_manager();
-    manager->lock();
-    jrp::EventJrp *jrp=(jrp::EventJrp *)cell->event<crypto::EventP2p>()->sub_;
-    vmp_bool ret=jrp->peersession_.forward();
-    manager->unlock();
-    return ret;
-}
-
 vmp::str JrpUI::peer_subject_f(vmp::str fingerprint)
 {
     event::Cell *cell=0;
@@ -433,21 +423,6 @@ vmp::str JrpUI::peer_nodetype_f(vmp::str fingerprint)
     return ret;
 }
 
-vmp_bool JrpUI::peer_forward_f(vmp::str fingerprint)
-{
-    event::Cell *cell=0;
-    manager_->lock();
-    if(!p2pcommon_->p2ptable_.search(fingerprint,&cell))
-    {
-        manager_->unlock();
-        vmp::except("jrp::JrpUI::peer_nodetype_f(fingerprint=%s) peer not found",fingerprint.c_str());
-    }
-    jrp::EventJrp *jrp=(jrp::EventJrp *)cell->event<crypto::EventP2p>()->sub_;
-    vmp_uint ret=jrp->peersession_.forward();
-    manager_->unlock();
-    return ret;
-}
-
 vmp::vector<vmp::str> JrpUI::search_peer(vmp::str input)
 {
     vmp::vector<vmp::str> ret;
@@ -676,14 +651,14 @@ vmp::vector<vmp::str> JrpUI::broadcastdata_peer_f(vmp::str fingerprint)
     return ret;
 }
  
-jrp::JrpReq *JrpUI::request(event::Cell *cell,json::JsonObj *jdata,vmp::Buf *payload,vmp::str forward)
+jrp::JrpReq *JrpUI::request(event::Cell *cell,json::JsonObj *jdata,vmp::Buf *payload)
 {
     event::Manager *manager=cell->get_manager();
     jrp::JrpReq *ret;
     manager->lock();
     try
     {
-        ret=jrpcommon_->new_request(cell,jdata,payload,forward);
+        ret=jrpcommon_->new_request(cell,jdata,payload);
     }
     catch(vmp::exception &x)
     {
@@ -697,7 +672,7 @@ jrp::JrpReq *JrpUI::request(event::Cell *cell,json::JsonObj *jdata,vmp::Buf *pay
     return ret;
 }
 
-jrp::JrpReq *JrpUI::request_f(vmp::str fingerprint,json::JsonObj *jdata,vmp::Buf *payload,vmp::str forward)
+jrp::JrpReq *JrpUI::request_f(vmp::str fingerprint,json::JsonObj *jdata,vmp::Buf *payload)
 {
     jrp::JrpReq *ret;
     event::Cell *cell;
@@ -709,7 +684,7 @@ jrp::JrpReq *JrpUI::request_f(vmp::str fingerprint,json::JsonObj *jdata,vmp::Buf
     }
     try
     {
-        ret=jrpcommon_->new_request(cell,jdata,payload,forward);
+        ret=jrpcommon_->new_request(cell,jdata,payload);
     }
     catch(vmp::exception &x)
     {
