@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 19/09/2024
+   Date last update: 05/12/2024
 */
 
 #include "json.h"
@@ -69,7 +69,7 @@ void japi_list(json::JsonObj *obj,json::JList *list)
     vmp::str datatype=list->jdata_type();
     jdata.new_data(obj,json::japi_type_list(datatype));
     jdata.set_text("datatype",datatype);
-    jdata.set_list("list",list,datatype); 
+    jdata.set_list("list",list); 
 }
 
 void japi_table(json::JsonObj *obj,vmp::str datatype)
@@ -90,18 +90,16 @@ void japi_table(json::JsonObj *obj,json::JTable *table)
     vmp::str datatype=table->jdata_type();
     jdata.new_data(obj,json::japi_type_table(datatype));
     jdata.set_text("datatype",datatype);
-    jdata.set_table("table",table,datatype); 
+    jdata.set_table("table",table); 
 }
 
 void japi_oper(json::JsonObj *obj,vmp::str id,json::JsonObj *input,vmp::Buf *bin)
 {
     vmp::except_check_pointer((void *) obj,"json::japi_oper(obj=Null)");
     json::JData jdata,tmp;
-    vmp::str itype;
     try
     {
         tmp.set(input);
-        itype=tmp.jtype();
     }
     catch(vmp::exception &x)
     {
@@ -116,7 +114,7 @@ void japi_oper(json::JsonObj *obj,vmp::str id,json::JsonObj *input,vmp::Buf *bin
         bin->index();
         jdata.set_text("bin",bin->read_xstr(bin->size()));
     }
-    jdata.set_subtype("input",input,itype);    
+    jdata.set_subtype("input",input);    
 
 }
 
@@ -132,11 +130,9 @@ void japi_oper_data(json::JsonObj *obj,vmp::str id,json::JsonObj *data,vmp::Buf
 {
     vmp::except_check_pointer((void *) obj,"json::japi_oper_data(obj=Null)");
     json::JData jdata,tmp;
-    vmp::str dtype;
     try
     {
         tmp.set(data);
-        dtype=tmp.jtype();
     }
     catch(vmp::exception &x)
     {
@@ -151,18 +147,16 @@ void japi_oper_data(json::JsonObj *obj,vmp::str id,json::JsonObj *data,vmp::Buf
         bin->index();
         jdata.set_text("bin",bin->read_xstr(bin->size()));
     }
-    jdata.set_subtype("data",data,dtype);
+    jdata.set_subtype("data",data);
 }
 
 void japi_oper_push(json::JsonObj *obj,vmp::str id,json::JsonObj *data,vmp::Buf *bin)
 {
     vmp::except_check_pointer((void *) obj,"json::japi_oper_push(obj=Null)");
     json::JData jdata,tmp;
-    vmp::str dtype;
     try
     {
         tmp.set(data);
-        dtype=tmp.jtype();
     }
     catch(vmp::exception &x)
     {
@@ -177,7 +171,7 @@ void japi_oper_push(json::JsonObj *obj,vmp::str id,json::JsonObj *data,vmp::Buf
         bin->index();
         jdata.set_text("bin",bin->read_xstr(bin->size()));
     }
-    jdata.set_subtype("data",data,dtype);
+    jdata.set_subtype("data",data);
 }
 
 void japi_oper_close(json::JsonObj *obj,vmp::str id,vmp_int code,vmp::str msg)
@@ -190,31 +184,28 @@ void japi_oper_close(json::JsonObj *obj,vmp::str id,vmp_int code,vmp::str msg)
     jdata.set_text("msg",msg);    
 }
 
-void japi_status(json::JsonObj *obj,vmp::str id)
+void japi_status(json::JsonObj *obj)
 {
     vmp::except_check_pointer((void *) obj,"json::japi_status(obj=Null)");
     json::JData jdata;
     jdata.new_data(obj,json::japi("status"));
-    jdata.set_text("id",id);
 }
 
-void japi_status_update(json::JsonObj *obj,vmp::str key,json::JsonObj *data,vmp::str id)
+void japi_status_update(json::JsonObj *obj,vmp::str key,json::JsonObj *data)
 {
     vmp::except_check_pointer((void *) obj,"json::japi_status_update(obj=Null)");
     json::JData jdata;
     jdata.new_data(obj,json::japi("statusupdate"));
     jdata.set_text("key",key);
     jdata.set_subtype("data",data);
-    jdata.set_text("id",id);
 }
 
-void japi_status_cancel(json::JsonObj *obj,vmp::str key,vmp::str id)
+void japi_status_cancel(json::JsonObj *obj,vmp::str key)
 {
     vmp::except_check_pointer((void *) obj,"json::japi_status_cancel(obj=Null)");
     json::JData jdata;
     jdata.new_data(obj,json::japi("statuscancel"));
     jdata.set_text("key",key);
-    jdata.set_text("id",id);
 }
 
 void japi_login(json::JsonObj *obj,vmp::str user,vmp::str password,vmp_bool md5_password)
@@ -250,5 +241,116 @@ void japi_login_b64_d(json::Json *json,vmp::str etoken)
     }
 }
 
+void japi_passwd(json::JsonObj *obj,vmp::str oldpassword,vmp::str password,vmp_bool md5_password)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_passwd(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("passwd"));
+    jdata.set_text("oldpassword",oldpassword);
+    jdata.set_text("password",password);
+    jdata.set_bool("md5_password",md5_password); 
+}
+
+void japi_userlist(json::JsonObj *obj)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_userlist(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("userlist"));
+}
+
+void japi_userinfo(json::JsonObj *obj,vmp::str user,vmp_uint permits,vmp_bool only_localhost)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_userinfo(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("userinfo"));
+    jdata.set_text("user",user);
+    jdata.set_integer_range("permits",0,vmp::INTMAX,(vmp_int)permits);
+    jdata.set_bool("only_localhost",only_localhost);
+}
+
+void japi_useradd(json::JsonObj *obj,vmp::str user,vmp::str password,vmp_uint permits,vmp_bool only_localhost,vmp_bool md5_password)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_useradd(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("useradd"));
+    jdata.set_text("user",user);
+    jdata.set_text("password",password);
+    jdata.set_integer_range("permits",0,vmp::INTMAX,(vmp_int)permits);
+    jdata.set_bool("only_localhost",only_localhost);
+    jdata.set_bool("md5_password",md5_password);
+}
+
+void japi_usermod(json::JsonObj *obj,vmp::str user,vmp_uint permits,vmp_bool only_localhost)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_usermod(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("usermod"));
+    jdata.set_text("user",user);
+    jdata.set_integer_range("permits",0,vmp::INTMAX,(vmp_int)permits);
+    jdata.set_bool("only_localhost",only_localhost);
+}
+
+void japi_userpasswd(json::JsonObj *obj,vmp::str user,vmp::str password,vmp_bool md5_password)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_userpasswd(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("userpasswd"));
+    jdata.set_text("user",user);
+    jdata.set_text("password",password);
+    jdata.set_bool("md5_password",md5_password);
+}
+
+void japi_userdel(json::JsonObj *obj,vmp::str user)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_userdel(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("userdel"));
+    jdata.set_text("user",user);
+}
+
+void japi_peerlist(json::JsonObj *obj)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_peerlist(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("peerlist"));
+}
+
+void japi_peerinfo(json::JsonObj *obj,vmp::str fingerprint,vmp::str subject,vmp_uint permits)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_peerinfo(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("peerinfo"));
+    jdata.set_text("fingerprint",fingerprint);
+    jdata.set_text("subject",subject);
+    jdata.set_integer_range("permits",0,vmp::INTMAX,(vmp_int)permits);
+}
+
+void japi_peeradd(json::JsonObj *obj,vmp::str fingerprint,vmp::str subject,vmp_uint permits)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_peeradd(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("peeradd"));
+    jdata.set_text("fingerprint",fingerprint);
+    jdata.set_text("subject",subject);
+    jdata.set_integer_range("permits",0,vmp::INTMAX,(vmp_int)permits);
+}
+
+void japi_peermod(json::JsonObj *obj,vmp::str fingerprint,vmp_uint permits)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_peermod(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("peermod"));
+    jdata.set_text("fingerprint",fingerprint);
+    jdata.set_integer_range("permits",0,vmp::INTMAX,(vmp_int)permits);
+}
+
+void japi_peerdel(json::JsonObj *obj,vmp::str fingerprint)
+{
+    vmp::except_check_pointer((void *) obj,"web::pkg::japi_peerdel(obj=Null)");
+    json::JData jdata;
+    jdata.new_data(obj,json::japi("peerdel"));
+    jdata.set_text("fingerprint",fingerprint);
+}
+
 }}
 
