@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- *Date last update: 01/03/2024
+ *Date last update: 24/10/2024
  */
 
 #include "net.h"
@@ -38,7 +38,7 @@ vmp::str UdpUI::identity(event::Cell *cell)
     net::EventConnection *conn=cell->event<net::EventConnection>();
     vmp_int type=conn->evt_connection_type();
     vmp::str strtype=conn->evt_connection_strtype();
-    net::Address *local=conn->evt_connection_localaddr(),*peer,*proxyaddr;
+    net::Address *local=conn->evt_connection_localaddr(),*peer;
     
     if((type == net::CONN_UDP4) || (type == net::CONN_UDP6))
         vmp::unicode::str_write(&ret,"%s:[%s:%s]",strtype.c_str(),local->host().c_str(),local->service().c_str());
@@ -51,10 +51,7 @@ vmp::str UdpUI::identity(event::Cell *cell)
     else if(type == net::CONN_UDPPROXY)
     {
         peer=conn->evt_connection_peeraddr();
-        proxyaddr=conn->evt_connection_proxyinfo()->addr();
-        vmp::unicode::str_write(&ret,"%s:[%s:%s]<->[%s:%s]<->[%s:%s]",strtype.c_str(),local->host().c_str(),local->service().c_str(),
-                                                           proxyaddr->host().c_str(),proxyaddr->service().c_str(),peer->host().c_str(),
-                                                           peer->service().c_str());
+        vmp::unicode::str_write(&ret,"%s:[%s:%s]<->[proxy]<->[%s:%s]",strtype.c_str(),local->host().c_str(),local->service().c_str(),peer->host().c_str(),peer->service().c_str());
     }
     return ret;
 }
@@ -138,7 +135,7 @@ event::Cell *UdpUI::new_udp6()
     return cell;
 }
 
-event::Cell *UdpUI::new_client(net::Address *peer,net::ProxyInfo *proxy)
+event::Cell *UdpUI::new_client(net::Address *peer,net::ProxyChain *proxy)
 {
     event::Cell *cell=0;
     manager_->lock();
@@ -154,6 +151,7 @@ event::Cell *UdpUI::new_client(net::Address *peer,net::ProxyInfo *proxy)
         vmp::except("net::UdpUI::new_client() '%s'",x.what());
     }
     manager_->unlock();
+    conn->evt_connection_udp_connect(cell);
     return cell;
 }
 
@@ -205,14 +203,14 @@ net::Address *UdpUI::peeraddr(event::Cell *cell)
     return ret;   
 }
 
-net::ProxyInfo *UdpUI::proxyinfo(event::Cell *cell)
+net::ProxyChain *UdpUI::proxychain(event::Cell *cell)
 {
     event::Manager *manager=cell->get_manager();
     manager->lock();
     net::EventConnection *conn=cell->event<net::EventConnection>();
-    net::ProxyInfo *ret=conn->evt_connection_proxyinfo();
+    net::ProxyChain *ret=conn->evt_connection_proxychain();
     manager->unlock();
-    return ret; 
+    return ret;
 }
 
 vmp_int UdpUI::connection_type(event::Cell *cell)
@@ -235,6 +233,16 @@ vmp::str UdpUI::connection_strtype(event::Cell *cell)
     return ret;
 }
 
+vmp_byte UdpUI::lastfrag(event::Cell *cell)
+{
+    event::Manager *manager=cell->get_manager();
+    manager->lock();
+    net::EventConnection *conn=cell->event<net::EventConnection>();
+    vmp_byte ret=conn->evt_connection_udplastfrag();
+    manager->unlock();
+    return ret;
+}
+
 }}
 
 
