@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 13/11/2020
+   Date last update: 13/09/2024
  */
 
 #include "packet.h"
@@ -99,6 +99,14 @@ void Packet::insert_data(packet::DataTypes *bytes)
     }
 }
 
+packet::DataTypes *Packet::get_data(vmp::str field)
+{
+    vmp_index i;
+    if(!search_.search(field,&i))
+        vmp::except("packet::Datatype::get_data(field=%s) not found",field.c_str());
+    return data_[i];
+}
+
 vmp::str Packet::get(vmp::str field)
 {
     vmp_index index;
@@ -150,7 +158,7 @@ void Packet::set(vmp::str field,vmp::str data)
     catch(vmp::exception &x)
     {
         vmp::except("packet::Packet::set() in packet '%s' check failed to insert data '%s' for field '%s'[%s]",
-                    type.c_str(),data.c_str(),field.c_str(),x.what());
+                    type_.c_str(),data.c_str(),field.c_str(),x.what());
     }
 }
 
@@ -259,6 +267,15 @@ PacketHelper::PacketHelper()
 	
     // udp
     insert_packet(packet::P_UDP,packet::Udp_D);
+    
+    // http request
+    insert_packet(packet::http::P_HTTP_REQUEST,packet::http::Http_Request_D);
+    
+    // http response
+    insert_packet(packet::http::P_HTTP_RESPONSE,packet::http::Http_Response_D);
+    
+    // websocket framing packet
+    insert_packet(packet::websocket::P_WEBSOCKET_FRAMING,packet::websocket::WebSocket_Framing_D);
 }
      
 PacketHelper::~PacketHelper()
@@ -667,5 +684,107 @@ void Udp_adjust_check(packet::Packet *packet)
     }
 }
 
+namespace http {
+
+packet::Packet *Http_Request_D()
+{
+    packet::Packet *p=new packet::http::Http_Request_P();
+    p->set("method","GET");
+    p->set("uri","/");
+    p->set("version","HTTP/1.1");
+    p->set("headers","");
+    p->set("body","");
+    return p;
+}
+
+packet::Packet *Http_Request(vmp::str method,packet::http::UriHelper *uri,vmp::str version,packet::http::HeadersHelper *headers,vmp::str body)
+{
+    packet::http::Http_Request_P *p=(packet::http::Http_Request_P *)packet::http::Http_Request_D();
+    p->set("method",method);
+    p->set_uri(uri);
+    p->set("version",version);
+    p->set_headers(headers);
+    p->set("body",body);
+    return p;
+}
+
+packet::Packet *Http_Response_D()
+{
+    packet::Packet *p=new packet::http::Http_Response_P();
+    return p;
+}
+
+packet::Packet *Http_Response(vmp::str version,vmp_int code,vmp::str reason,packet::http::HeadersHelper *headers,vmp::str body)
+{
+    packet::http::Http_Response_P *p=(packet::http::Http_Response_P *)packet::http::Http_Response_D();
+    p->set("version",version);
+    p->set_code(code);
+    p->set("reason",reason);
+    p->set_headers(headers);
+    p->set("body",body);
+    return p;
+}
+}
+
+namespace websocket {
+
+packet::Packet *WebSocket_Framing_D()
+{
+    return (Packet *) new packet::websocket::WebSocket_Framing_P();
+}
+
+packet::Packet *WebSocket_Framing(vmp::str fin,vmp::str rsv1,vmp::str rsv2,vmp::str rsv3,vmp::str opcode,vmp::str masking_key,vmp::str payload)
+{
+    Packet *ret=packet::websocket::WebSocket_Framing_D();
+    ret->set("fin",fin);
+    ret->set("rsv1",rsv1);
+    ret->set("rsv2",rsv2);
+    ret->set("rsv3",rsv3);
+    ret->set("opcode",opcode);
+    if(masking_key != "")
+    {
+        ret->set("mask","set");
+        ret->set("masking_key",masking_key);
+    }
+    ret->set("payload",payload);
+    return ret;
+}
+
+packet::Packet *WebSocket_Framing_Ping(vmp_size bodylen)
+{
+    vmp::Buf buf;
+    Packet *ret=packet::websocket::WebSocket_Framing_D();
+    ret->set("fin","set");
+    ret->set("opcode","ping");
+    buf.random_bytes(bodylen);
+    buf.index();
+    ret->set("payload",buf.read_xstr(buf.size()));
+    return ret;
+    
+}
+packet::Packet *WebSocket_Framing_Pong(vmp::str payload)
+{
+    Packet *ret=packet::websocket::WebSocket_Framing_D();
+    ret->set("fin","set");
+    ret->set("opcode","pong");
+    ret->set("payload",payload);
+    return ret;
+}
+
+packet::Packet *WebSocket_Framing_Close(vmp_size code,vmp::str reason)
+{
+    Packet *ret=packet::websocket::WebSocket_Framing_D();
+    ret->set("fin","set");
+    ret->set("opcode","close");
+    vmp::Buf buf;
+    buf.write_size(code,2);
+    buf.write_str(reason);
+    buf.index();
+    ret->set("payload",buf.read_xstr(buf.size())); 	
+    return ret;
+}
+
+}
+
 }}
 
