@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/05/2024
+   Date last update: 28/11/2024
  */
 
 #include "pylib.h"
@@ -97,7 +97,7 @@ vmp_char pychar_aschar(pylib::Objref *obj)
     }
     try
     {
-        vmp::str unicode=pyunicode_asstring(obj);
+        vmp::str unicode=pylib::pyunicode_asstring(obj);
         if(unicode.size() == 1)
             return static_cast<vmp_char>(unicode[0]);
     }
@@ -286,6 +286,12 @@ pylib::Objref *pyunicode_decode(vmp::str str)
     return PyUnicode_DecodeLatin1(str.c_str(),str.size(),0);
 }
 
+vmp::str pyobject_asstring(pylib::Objref *obj)
+{
+    pylib::Objref *repr=PyObject_Repr(obj);
+    return pylib::pyunicode_asstring(repr);
+}
+
 void pyerr_occurred()
 {
     pylib::Objref *occurred=PyErr_Occurred();
@@ -555,15 +561,16 @@ pylib::Objref *pycallable_call(pylib::Objref *callable,pylib::Objref *tuple)
     pylib::Objref *ret=PyObject_Call(callable,tuple,0);
     if(ret == 0)
     {
+       vmp::str err="undef";
        try
        {
            pyerr_occurred();
        }
        catch(vmp::exception &x)
        {
-           vmp::except_s(x.what());
+           err=x.what();
        }
-       vmp::except_s("Callback python error undef error");
+       vmp::exit_failure("Callback python '%s' error '%s'",pylib::pyobject_asstring(callable).c_str(),err.c_str());
     }
     return ret;
 }
