@@ -16,13 +16,28 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/11/2019
+   Date last update: 09/05/2014
  */
 
 #include "vmp.h"
 
 namespace vampiria { namespace vmp {
 
+void *malloc_wrap(vmp_size size)
+{
+    void *ret=malloc(size);
+    if(ret == 0)
+       vmp::except_alloc();
+    return ret;
+}
+
+void free_wrap(void **ptr)
+{
+    if((*ptr) != 0)
+       free(*ptr);
+    (*ptr)=0;
+}
+
 void bzero_wrap(void *s,vmp_size n)
 {
     bzero(s,n);
