@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 04/04/2024
+   Date last update: 07/06/2024
  */
 
 #include "config.h"
@@ -59,6 +59,19 @@ vmp::str vampiria_frm(vmp::str subpath)
     return vmp::fs::union_path(VFRMWK,subpath);   
 }
 
+vmp::str vampiria_web_root()
+{
+    return VWEB;
+}
+
+vmp::str vampiria_web(vmp::str libname,vmp::str subpath)
+{
+    vmp::str spath=vmp::fs::union_path(vmp::env::vampiria_web_root(),libname);
+    if(!vmp::fs::isdir(spath))
+        vmp::except("Software name '%s' Not Found",libname.c_str());
+    return vmp::fs::union_path(spath,subpath);
+}
+
 vmp::str vampiria_bin(vmp::str name)
 {
     vmp::str path=vmp::fs::union_path(VEXEC,name);
@@ -129,6 +142,15 @@ vmp::str module_main_path(vmp::str name)
     return mpath; 
 }
 
+vmp::str module_web_path(vmp::str name,vmp::str subpath)
+{
+    vmp::str s=vmp::fs::union_path(VMODULEJS,subpath);
+    vmp::str mpath=vmp::env::module_path(name,s);
+    if(!vmp::fs::isdir(mpath))
+        vmp::except("Module name '%s' js directory %s Not Found",name.c_str(),s.c_str());
+    return mpath; 
+}
+
 vmp::str module_manifest(vmp::str name)
 {
     vmp::str manifest=vmp::fs::union_path(vmp::env::module_main_path(name),VMANIFEST);
