@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 23/04/2024
+   Date last update: 27/12/2024
  */
 
 #include <map>
@@ -91,25 +91,25 @@ class Table
              @param key key table
              @param pdata pointer data value
              @sa data_
-             
-            
+             @return true if the data has been updated and the old date is inserted in pdata, or false if it is simply entered
         */
-        void update(KEY key,DATA *pdata)
+        vmp_bool update(KEY key,DATA *pdata)
         {
              DATA tmp;        
              if(!search(key,&tmp))
              {
                  data_.insert(std::pair<KEY,DATA>(key,*pdata));
-                 (*pdata)=0;
+                 return false;
              }
              else
              {
-                 DATA *tmp=pdata;
+                 DATA *tmp2=pdata;
                  cancel(key,pdata);
-                 data_.insert(std::pair<KEY,DATA>(key,(*tmp)));
+                 data_.insert(std::pair<KEY,DATA>(key,(*tmp2)));
              }
+             return true;
         }
-
+        
         //! Cancel a value in the table                
         /*!
             @param key key table
