@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 04/01/2024
+   Date last update: 11/11/2024
  */
 
 #include <time.h>
@@ -261,6 +261,12 @@ class Localtime
             @return the day number of the year stored
         */
         vmp_uint year_day();
+        
+        //! Returns true if it reads summer time
+        /*!
+            @return true if summer type or false if normal time or except if the information is not available
+        */
+        vmp_bool summertime();
 };
 
 //!Timer object utility
