@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 30/05/2024
+   Date last update: 02/12/2024
  */
 
 #include "vmp.h"
@@ -164,7 +164,7 @@ vmp_int str_todigit_range(vmp::str istr,vmp_int min,vmp_int max)
         vmp::except("Min value %d not less max value %d in input",min,max);
     vmp_int ret=vmp::unicode::str_todigit(istr);
     if((ret < min) || (ret > max))
-        vmp::except("%s not integer in range [%d,%d]",istr.c_str(),min,max);
+        vmp::except("'%s' not integer in range [%d,%d]",istr.c_str(),min,max);
     return ret; 
 }
 
@@ -181,7 +181,7 @@ vmp_int64 str_todigit64_range(vmp::str istr,vmp_int64 min,vmp_int64 max)
         vmp::except("Min value %lld not less max value %lld in input",min,max);
     vmp_int ret=vmp::unicode::str_todigit64(istr);
     if((ret < min) || (ret > max))
-        vmp::except("%s not integer in range [%lld,%lld]",istr.c_str(),min,max);
+        vmp::except("'%s' not integer in range [%lld,%lld]",istr.c_str(),min,max);
     return ret; 
 }
 
@@ -200,7 +200,7 @@ vmp_real str_toreal_range(vmp::str dstr,vmp_real min,vmp_real max)
         vmp::except("Min value %f not less max value %f in input",min,max);
     vmp_real ret=vmp::unicode::str_toreal(dstr);
     if((ret < min) || (ret > max))
-        vmp::except("%s not double in range [%f,%f]",dstr.c_str(),min,max);
+        vmp::except("'%s' not real in range [%f,%f]",dstr.c_str(),min,max);
     return ret; 
 }
 
@@ -426,7 +426,7 @@ vmp::str str_format_end(vmp::str content)
             break;
     if(i < 0)
         return "";
-    return content.substr(0,i+1);
+    return vmp::unicode::str_sub(content,0,i+1); 
 }
 
 vmp::str str_extract_char(vmp::str str,vmp::str clist)
