@@ -29,10 +29,10 @@ name="clientjrp"
 
 pysetup=pybuild.pysetup()
 pysetup.dirmain="{0}{1}/".format(config.gmodules_,name)
-pysetup.dependencies=['vmp','vmp_plugin','vmp_event','vmp_openssl4','vmp_json']
+pysetup.dependencies=['vmp','vmp_net','vmp_plugin','vmp_event','vmp_crypto','vmp_json','vmp_jrp']
 
 def description():
-    return "Module used for creating jrp clients,by running an 'openssl.clientjrp' plugin"
+    return "Module used for creating jrp clients,by running an 'client.jrp' plugin"
     
 def install():
     pybuild.pybuild(pysetup)
